//
// Copyright (c) 2002 - Novell Inc. - All Rights Reserved.
//
// File:         utils.js
// Description:  Javascript utilities
//
// This software is the proprietary information of Novell
// Inc.
//


var IE = document.all;
var NS6 = document.getElementById && ! IE;

//*******************************************************
//                    Number Utilities 
//*******************************************************

//
// Checks if the number specified is a positive integer
//
function isPosInteger(n) {
   var re = /^(0|[1-9]\d*)$/
   var s = n.toString();
   return(re.test(s));
}

//
// Checks if the number specified is within a range. If
// the 3rd argument (max) is not specified the upper
// limit would not be checked.
//
function isInRange(n, min, max) {
   // check lower limit
   if (n < min)
      return false;

   // if specified, check upper limit
   if (max != "" && n > max)
      return false;

   return true;
}

//*******************************************************
//                   String Utilities
//*******************************************************

//
// Trims the leading and trailing spaces from a string.
//
function trim(s) {
   var j = s.length-1;
   while (j > 0 && s.charAt(j) == ' ') j--;
      
   var i = 0;
   while (i < j && s.charAt(i) == ' ') i++;

   return s.substring(i,j+1);
}

//
// Checks if the specified string is empty.
//
function isEmpty(s) {
   if (s == null) return true;
   var t = trim(s);
   return (t.length == 0);
}

//
// Checks if a string's length is within the limits
// specified. If the 3rd argument (max) is not
// specified, the upper limit would not be checked.
//
function isValidLength(s, min, max) {
   return isInRange(s.length, min, max);
}

//
// Checks if the string specified is a valid email
// address.
//
function isValidEmail(email) {
   var r1 = new RegExp("(@.*@)|(\\.\\.)|(@\\.)|(^\\.)");
   var r2 = new RegExp("^.+\\@(\\[?)[a-zA-Z0-9\\-\\.]+\\.([a-zA-Z]{2,4}|[0-9]{1,3})(\\]?)$");
   return(!r1.test(email) && r2.test(email));
}

//
// Returns a formated string using the given arguments .
//
function formatMessage(s,args) {
   if ((s == null)||(args == null)) return s;
   for (var i = 0; i < args.length ; i++){
      var r = new RegExp("\\{"+i+"\\}");
      s = s.replace(r, args[i]);
   }
   return s;
}


//*******************************************************
//                 Date & Time Utilities
//*******************************************************

//
// Checks if the specified year is a leap year.
//
function isLeapYear(year) {
   return (((year % 4) == 0) && ((year % 100) != 0) || ((year % 400) == 0));
}

//
// Returns the number of days in a month given the 
// month's number (1 to 12) and the year.
//
function getDaysInMonth(month, year) {
   var days = 31;

   if (month == 4 || month == 6 || month == 9 || month == 11) {
      days = 30;
   }

   else if (month == 2) {
      days = isLeapYear(year) ? 29 : 28;
   }

   return days;
}

//
// Checks if the specified date is valid.
//
function isValidDate(dd, mm, yyyy) {
   // do base 10 convertion for day, month, and year
   // because two digit entries might begin with zeros
   var day = parseInt(dd, 10);
   var month = parseInt(mm, 10);
   var year = parseInt(yyyy, 10);

   // check if any of the arguments is not a number
   if (isNaN(day) || isNaN(month) || isNaN(year))
      return false;

   // check the month
   if (month < 0  || month > 11)
      return false;

   // check the day
   var days = getDaysInMonth(month+1, year);
   if (day < 1 || day > days)
      return false;

   return true;
}
